searchNodes=[{"doc":"Shin is a simple Elixir client for the Shibboleth IdP's admin features. Currently it can collect metrics and trigger service reloads. Shin can be used to gather information about your IdP servers such as Java version and IdP version, and can also collect any other information defined as a metric within the IdP. Shin can return the raw data or reformat it into simpler reports. The Shibboleth IdP will automatically reload valid configuration files but may stop retrying if passed an incorrect file. Shin can be used to prompt the IdP to immediately reload parts of its configuration. ## Overview The Shin module contains a few useful functions that are probably enough for most tasks. The Shin.Metrics and Shin.Reports modules provide extra functions for handling the returned metrics. Shin.Attributes and Shin.Assertion give access to predictions of attribute data as released to SPs. The Shin.Metadata module has functions for querying metadata and resetting metadata providers. Shin.Service gives more information about sub-service status. ### Defining an IdP target To define an IdP using a default configuration you only need the base URL of the IdP service iex&gt; Shin.idp(&quot;https://example.com/idp&quot;) {:ok, %Shin.IdP{ base_url: &quot;https://example.com/idp&quot;, metric_groups: [:core, :idp, :logging, :access, :metadata, :nameid, :relyingparty, :registry, :resolver, :filter, :cas, :bean], metrics_path: &quot;profile/admin/metrics&quot;, no_dns_check: false, reload_path: &quot;profile/admin/reload-service&quot;, reloadable_services: %{ access_control: &quot;shibboleth.ReloadableAccessControlService&quot;, attribute_filter: &quot;shibboleth.AttributeFilterService&quot;, attribute_registry: &quot;shibboleth.AttributeRegistryService&quot;, attribute_resolver: &quot;shibboleth.AttributeResolverService&quot;, cas_registry: &quot;shibboleth.ReloadableCASServiceRegistry&quot;, managed_beans: &quot;shibboleth.ManagedBeanService&quot;, metadata_resolver: &quot;shibboleth.MetadataResolverService&quot;, nameid_generator: &quot;shibboleth.NameIdentifierGenerationService&quot;, relying_party_resolver: &quot;shibboleth.RelyingPartyResolverService&quot;, logging: &quot;shibboleth.LoggingService&quot; }, timeout: 2000 }} If your IdP has different paths, metrics groups or reloadable services you can specify them as options. Functions in the top-level Shin module can also be passed a base URL if no configuration is needed.Downloading raw metrics {:ok, metrics} = Shin.metrics(idp) {:ok, metrics} = Shin.metrics(idp, :core) list_of_gauges = Shin.Metrics.gauge_ids(metrics) hostname = Shin.Metrics.gauge(metrics, &quot;host.name&quot;)Producing a simplified report {:ok, report} = Shin.report(idp, :system_info) report.cores # =&gt; 4Triggering a service reload {:ok, message} = Shin.reload_service(idp, &quot;shibboleth.AttributeFilterService&quot;) {:ok, message} = Shin.reload_service(idp, :attribute_filter)Listing attribute data released to an SP {:ok, attr_data} = Shin.attributes(idp, &quot;https://test.ukfederation.org.uk/entity&quot;, &quot;pete&quot;) Shin.Attributes.values(attr_data, &quot;eduPersonEntitlement&quot;) =&gt; [&quot;urn:mace:dir:entitlement:common-lib-terms&quot;] Shin.Attributes.names(attr_data) =&gt; [&quot;eduPersonEntitlement&quot;, &quot;eduPersonPrincipalName&quot;, &quot;eduPersonScopedAffiliation&quot;, &quot;eduPersonUniqueID&quot;, &quot;o&quot;]","ref":"Shin.html","title":"Shin","type":"module"},{"doc":"Looks up attributes likely to be released to the specified SP for the specified user, returning them as an XML text in a result tuple.The assertion is not validated or parsed in any way. It should accurately reflect the assertion and attributes released by the IdP.If your IdP is using another IdP as a proxy then any attributes derived from the upstream IdP will be missing: only attributes sourced or created by the Shibboleth IdP can be returned.Pass the IdP, followed by the SP's entity ID and the username/principal of the user.Examples {:ok, assertion_xml} = Shin.assertion(idp, &quot;https://test.ukfederation.org.uk/entity&quot;, &quot;pete&quot;)","ref":"Shin.html#assertion/4","title":"Shin.assertion/4","type":"function"},{"doc":"Looks up attributes likely to be released to the specified SP for the specified user, returning them as a map in a result tuple.Functions in the Shin.Attributes module act as getters to retrieve information from the map.If your IdP is using another IdP as a proxy then any attributes derived from the upstream IdP will be missing: only attributes sourced or created by the Shibboleth IdP can be returned.Pass the IdP, followed by the SP's entity ID and the username/principal of the user.Examples {:ok, attribute_data} = Shin.attributes(idp, &quot;https://test.ukfederation.org.uk/entity&quot;, &quot;pete&quot;)","ref":"Shin.html#attributes/4","title":"Shin.attributes/4","type":"function"},{"doc":"Returns a structure representing an IdP and its configuration.Pass a URL as the first (and required) parameter. URL validation can be skipped by specifying no_dns_check: true as an option. Other options will replace defaults for the IdP's configuration.The URL is the base URL of the IdP service, not its entity ID. Normally this will include the &quot;/idp&quot; path.If you are not customising the configuration of the IdP at all you can skip creating an IdP struct and just pass the URL directly to the functions in this module. However, the other Shin modules require the full IdP struct.Examples {:ok, idp} = Shin.idp(&quot;https://example.com/idp&quot;) {:ok, idp} = Shin.idp(&quot;https://hostnamedoesnotexist.com/idp&quot;, no_dns_check: true) {:ok, idp} = Shin.idp(&quot;https://example.com/idp&quot;, metric_groups: [:core, :idp, :logging, :metadata, :errors])","ref":"Shin.html#idp/2","title":"Shin.idp/2","type":"function"},{"doc":"Looks up metadata for the specified SP, returning metadata XML as a string.Metadata is looked up using the IdP's metadata providers, using each one in turn until metadata is found.The metadata XML is not parsed or validated in any way. If you need that sort of thing please take a look at the Smee library.Pass the IdP and the entity ID of the SP.Examples {:ok, metadata_xml} = Shin.metadata(idp, &quot;https://test.ukfederation.org.uk/entity&quot;)","ref":"Shin.html#metadata/3","title":"Shin.metadata/3","type":"function"},{"doc":"Returns default (all) raw metrics from the IdP as a map.Pass an IdP as the only parameter.Examples {:ok, metrics} = Shin.metrics(idp)","ref":"Shin.html#metrics/1","title":"Shin.metrics/1","type":"function"},{"doc":"Returns the specified raw metrics group from the IdP as a map.Pass an IdP struct or URL binary as the first parameter and the name of the group as the second (as atom or binary)Examples {:ok, metrics} = Shin.metrics(idp, :core)","ref":"Shin.html#metrics/2","title":"Shin.metrics/2","type":"function"},{"doc":"Sends a reload request for the specified metadata provider to the IdP. This should cause the IdP to reset and reload the metadata associated with that provider.Pass an IdP as the first parameter. The second parameter must be the provider name. You can list active providers with Shin.Metadata.providers/1Examples {:ok, _} = Shin.reload_metadata(idp, &quot;ukFederationMDQ&quot;)","ref":"Shin.html#reload_metadata/3","title":"Shin.reload_metadata/3","type":"function"},{"doc":"Sends a reload request for the specified service to the IdP. This should cause the IdP to reload the configuration for that service.Pass an IdP as the first parameter. The second parameter is either a full service ID or an alias provided by Shin.Examples {:ok, message} = Shin.reload_service(idp, &quot;shibboleth.MetadataResolverService&quot;) {:ok, message} = Shin.reload_service(&quot;https://example.com/idp&quot;, :metadata_resolver)","ref":"Shin.html#reload_service/3","title":"Shin.reload_service/3","type":"function"},{"doc":"Returns reformatted metrics as a simplified structure.The only parameter is the IdP struct or URL. The default report will be returned.Examples {:ok, report} = Shin.report(idp)","ref":"Shin.html#report/1","title":"Shin.report/1","type":"function"},{"doc":"Returns metrics reformatted using the specified module.The first parameter is the IdP struct or URL, the second is the alias or module name for the report processor.Examples {:ok, report} = Shin.report(idp, :system_info) {:ok, report} = Shin.report(idp, Shin.Reports.IdPInfo)","ref":"Shin.html#report/2","title":"Shin.report/2","type":"function"},{"doc":"Looks up information about the specified Shibboleth IdP subservice - things like the logging subsystem, or attribute filters.At the moment the only useful information concerns when the service restarted (or failed to restart)The service can be specified using the full Shibboleth service ID or a Shin service alias. These are listed in your IdP struct.Examples {:ok, info} = Shin.service(idp, &quot;shibboleth.AttributeRegistryService&quot;)","ref":"Shin.html#service/3","title":"Shin.service/3","type":"function"},{"doc":"Queries a Shibboleth IdP for simulated attribute assertions - producing XML that should be similar to the SAML sent to an SP, containing the same user information.The SAML assertion XML is not validated or parsed in any way. It should accurately reflect the assertion and attributes released by the IdP.If your IdP is using another IdP as a proxy then any attributes derived from the upstream IdP will be missing: only attributes sourced or created by the Shibboleth IdP can be returned.","ref":"Shin.Assertion.html","title":"Shin.Assertion","type":"module"},{"doc":"Looks up attributes likely to be released to the specified SP for the specified user, returning them as an XML text in a result tuple.Pass the IdP, followed by the SP's entity ID and the username/principal of the user.Examples {:ok, assertion_xml} = Shin.Assertion.query(idp, &quot;https://test.ukfederation.org.uk/entity&quot;, &quot;pete&quot;)","ref":"Shin.Assertion.html#query/4","title":"Shin.Assertion.query/4","type":"function"},{"doc":"Looks up attributes likely to be released to the specified SP for the specified user, returning XML as a binary string.Pass the IdP, followed by the SP's entity ID and the username/principal of the user.Examples assertion_xml = Shin.Assertion.query!(idp, &quot;https://test.ukfederation.org.uk/entity&quot;, &quot;pete&quot;)","ref":"Shin.Assertion.html#query!/4","title":"Shin.Assertion.query!/4","type":"function"},{"doc":"Queries a Shibboleth IdP for attributes similar to the those sent to the specified SP for a user.Other functions in this module act as getters to retrieve information from the map.If your IdP is using another IdP as a proxy then any attributes derived from the upstream IdP will be missing: only attributes sourced or created by the Shibboleth IdP can be returned.","ref":"Shin.Attributes.html","title":"Shin.Attributes","type":"module"},{"doc":"Returns a map of attribute friendly-names and values, taken from the attribute query results.(Friendly names are the LDAP-style, relatively human-friendly names of SAML attributes, rather than their URIs)Examples attributes = Shin.Attributes.attributes(query_results)","ref":"Shin.Attributes.html#attributes/1","title":"Shin.Attributes.attributes/1","type":"function"},{"doc":"Returns a list of all attribute friendly-names in the query results.(Friendly names are the LDAP-style, relatively human-friendly names of SAML attributes, rather than their URIs)Examples {:ok, report} = Shin.Attributes.names(query_results)","ref":"Shin.Attributes.html#names/1","title":"Shin.Attributes.names/1","type":"function"},{"doc":"Returns the principal/username when passed attribute query results.(This is identical to username/1)Examples &quot;pete&quot; = Shin.Attributes.principal(query_results)","ref":"Shin.Attributes.html#principal/1","title":"Shin.Attributes.principal/1","type":"function"},{"doc":"Looks up attributes likely to be released to the specified SP for the specified user, returning them as a map in a result tuple.Examples {:ok, query_results} = Shin.Attributes.query(idp, &quot;https://test.ukfederation.org.uk/entity&quot;, &quot;pete&quot;)","ref":"Shin.Attributes.html#query/4","title":"Shin.Attributes.query/4","type":"function"},{"doc":"Looks up attributes likely to be released to the specified SP for the specified user, returning them as a map.Examples query_results = Shin.Attributes.query!(idp, &quot;https://test.ukfederation.org.uk/entity&quot;, &quot;pete&quot;)","ref":"Shin.Attributes.html#query!/4","title":"Shin.Attributes.query!/4","type":"function"},{"doc":"Returns the entityID of the SP that is supposedly &quot;requesting&quot; the attributes(This is the same as sp/1)Examples &quot;https://test.ukfederation.org.uk/entity&quot; = Shin.Attributes.requester(query_results)","ref":"Shin.Attributes.html#requester/1","title":"Shin.Attributes.requester/1","type":"function"},{"doc":"Returns the entityID of the SP that is supposedly &quot;requesting&quot; the attributes(This is the same as requester/1)Examples &quot;https://test.ukfederation.org.uk/entity&quot; = Shin.Attributes.sp(query_results)","ref":"Shin.Attributes.html#sp/1","title":"Shin.Attributes.sp/1","type":"function"},{"doc":"Returns the principal/username when passed attribute query results.(This is identical to principal/1)Examples &quot;pete&quot; = Shin.Attributes.username(query_results)","ref":"Shin.Attributes.html#username/1","title":"Shin.Attributes.username/1","type":"function"},{"doc":"Returns the values of the specified attribute in the query results.Examples [&quot;urn:mace:dir:entitlement:common-lib-terms&quot;] = Shin.Attributes.values(attr_data, &quot;eduPersonEntitlement&quot;)","ref":"Shin.Attributes.html#values/2","title":"Shin.Attributes.values/2","type":"function"},{"doc":"This module contains the IdP structure used to configure requests to a particular IdP. The defaults should work for a typical fresh installation of Shibboleth IdP v4, but may require customisation if the IdP has a different path for endpoints, or additional metrics groups, etc.","ref":"Shin.IdP.html","title":"Shin.IdP","type":"module"},{"doc":"Returns a structure representing an IdP and its configuration.Pass a URL as the only parameter (although it will pass-through existing IdP stucts too)The URL is the base URL of the IdP service, not its entity ID. Normally this will include the &quot;/idp&quot; path.Examples{:ok, idp} = Shin.IdP.configure(&quot;https://example.com/idp&quot;) {:ok, idp} = Shin.IdP.configure(idp) # pass-through an existing IdP struct","ref":"Shin.IdP.html#configure/1","title":"Shin.IdP.configure/1","type":"function"},{"doc":"Returns a structure representing an IdP and its configuration.Pass a URL as the first (and required) parameter. URL validation can be skipped by specifying no_dns_check: true as an option. Other options will replace defaults for the IdP's configuration.The URL is the base URL of the IdP service, not its entity ID. Normally this will include the &quot;/idp&quot; path.Examples{:ok, idp} = Shin.IdP.configure(&quot;https://example.com/idp&quot;) {:ok, idp} = Shin.IdP.configure(&quot;https://hostnamedoesnotexist.com/idp&quot;, no_dns_check: true) {:ok, idp} = Shin.IdP.configure(&quot;https://example.com/idp&quot;, metric_groups: [:core, :idp, :logging, :metadata, :errors])","ref":"Shin.IdP.html#configure/2","title":"Shin.IdP.configure/2","type":"function"},{"doc":"Checks if a service ID or service alias is present in the IdP configuration.Returns true or falseExamples Shin.IdP.is_reloadable?(idp, :attribute_registry) # =&gt; true","ref":"Shin.IdP.html#is_reloadable?/2","title":"Shin.IdP.is_reloadable?/2","type":"function"},{"doc":"Return a list of metric groups for the IdP, as atoms.ExamplesShin.IdP.metric_groups(idp) # =&gt; [:core, :idp, :logging, :access, :metadata, :nameid, :relyingparty, :registry, :resolver, :filter, :cas, :bean]","ref":"Shin.IdP.html#metric_groups/1","title":"Shin.IdP.metric_groups/1","type":"function"},{"doc":"Returns the base metrics path (for all metrics) for an IdPExamples Shin.IdP.metrics_path(idp) # =&gt; metrics_path: &quot;https://example.com/idp/profile/admin/metrics&quot;,","ref":"Shin.IdP.html#metrics_path/1","title":"Shin.IdP.metrics_path/1","type":"function"},{"doc":"Returns the base metrics path for the specified group at an IdPExamples Shin.IdP.metrics_path(idp, :core) # =&gt; metrics_path: &quot;https://example.com/idp/profile/admin/metrics/core&quot;,","ref":"Shin.IdP.html#metrics_path/2","title":"Shin.IdP.metrics_path/2","type":"function"},{"doc":"Return a list of service aliases as atoms.These can be passed instead of the full Shibboleth service ID.ExamplesShin.IdP.service_aliases(idp) # =&gt; [:relying_party_resolver, :metadata_resolver, :attribute_registry, :attribute_resolver, :attribute_filter ...]","ref":"Shin.IdP.html#service_aliases/1","title":"Shin.IdP.service_aliases/1","type":"function"},{"doc":"Return a list of service IDs, as used by the Shibboleth IdP software.ExamplesShin.IdP.service_ids(idp) # =&gt; [&quot;shibboleth.RelyingPartyResolverService&quot;, &quot;shibboleth.MetadataResolverService&quot;, &quot;shibboleth.LoggingService&quot; ...]","ref":"Shin.IdP.html#service_ids/1","title":"Shin.IdP.service_ids/1","type":"function"},{"doc":"Checks if a metric group is present in the IdP configuration and returns a normalised version.Returns an atom.Examples Shin.IdP.validate_metric_group(idp, &quot;core&quot;) # =&gt; :core","ref":"Shin.IdP.html#validate_metric_group/2","title":"Shin.IdP.validate_metric_group/2","type":"function"},{"doc":"Checks if a service ID or service alias is present in the IdP configuration and returns a normalised version.Returns the full Shibboleth IdP service ID if passed an alias atom.Examples Shin.IdP.validate_service(idp, :attribute_registry) # =&gt; &quot;shibboleth.AttributeRegistryService&quot;","ref":"Shin.IdP.html#validate_service/2","title":"Shin.IdP.validate_service/2","type":"function"},{"doc":"","ref":"Shin.IdP.html#t:t/0","title":"Shin.IdP.t/0","type":"type"},{"doc":"Queries and reloads metadata at the IdP. Metadata for SAML entities can be downloaded and metadata providers can be reset.The module can be used to warm metadata caches, force reloads of metadata providers without restarting the IdP, and debug metadata source issues.","ref":"Shin.Metadata.html","title":"Shin.Metadata","type":"module"},{"doc":"Similar to query3 but no metadata is returned - its purpose is to prime the IdP's cached metadata.The IDs of entities that were actually found and cached will be returned as a list.Examples [&quot;https://test.ukfederation.org.uk/entity&quot;] = Shin.Metadata.cache(idp, &quot;https://test.ukfederation.org.uk/entity&quot;) [&quot;https://test.ukfederation.org.uk/entity&quot;] = Shin.Metadata.cache(idp, [&quot;https://test.ukfederation.org.uk/entity&quot;, &quot;http://example.com/fake&quot;])","ref":"Shin.Metadata.html#cache/2","title":"Shin.Metadata.cache/2","type":"function"},{"doc":"Lists active/known metadata providers at the IdP.Each metadata provider is a source of entity metadata. Shin makes a metrics API query to find them.Examples providers = Shin.Metadata.providers(idp)","ref":"Shin.Metadata.html#providers/1","title":"Shin.Metadata.providers/1","type":"function"},{"doc":"Query the IdP for metadata, returning the XML metadata for the specified entity ID if it can be found by the IdP.Metadata is looked up using the IdP's metadata providers, using each one in turn until metadata is found.The metadata XML is not parsed or validated in any way. If you need that sort of thing please take a look at the Smee library.Pass the IdP and the entity ID of the SP.Examples {:ok, metadata_xml} = Shin.Metadata.query(idp, &quot;https://test.ukfederation.org.uk/entity&quot;)","ref":"Shin.Metadata.html#query/3","title":"Shin.Metadata.query/3","type":"function"},{"doc":"Query the IdP for metadata, returning the XML metadata for the specified entity ID if it can be found by the IdP.Metadata is looked up using the IdP's metadata providers, using each one in turn until metadata is found.The metadata XML is not parsed or validated in any way. If you need that sort of thing please take a look at the Smee library.Pass the IdP and the entity ID of the SP.Examples metadata_xml = Shin.Metadata.query!(idp, &quot;https://test.ukfederation.org.uk/entity&quot;)","ref":"Shin.Metadata.html#query!/3","title":"Shin.Metadata.query!/3","type":"function"},{"doc":"Sends a reload request for the specified metadata provider to the IdP. This should cause the IdP to reset and reload the metadata associated with that provider.Pass an IdP as the first parameter. The second parameter must be the provider name. You can list active providers with Metadata.providers/1Examples {:ok, _} = Shin.Metadata.reload(idp, &quot;ukFederationMDQ&quot;)","ref":"Shin.Metadata.html#reload/3","title":"Shin.Metadata.reload/3","type":"function"},{"doc":"This module contains convenient functions for retrieving and processing the metrics data provided by a Shibboleth IdP.","ref":"Shin.Metrics.html","title":"Shin.Metrics","type":"module"},{"doc":"Return the value for a gauge.Specify the metrics map and key for the value to be extracted (assuming it's in a value: field)Examples Shin.Metrics.gauge(metrics, &quot;cores.available&quot;) # =&gt; 8","ref":"Shin.Metrics.html#gauge/2","title":"Shin.Metrics.gauge/2","type":"function"},{"doc":"List the keys for all gauges in the metrics.Requires a metrics map as the only parameter.Examples Shin.Metrics.gauge_ids(metrics) # =&gt; [&quot;cores.available&quot;, &quot;host.name&quot;, &quot;java.class.path&quot; ...]","ref":"Shin.Metrics.html#gauge_ids/1","title":"Shin.Metrics.gauge_ids/1","type":"function"},{"doc":"Returns a map of all gauges and their extracted values from the metrics data.Examples Metrics.gauges(metrics) # =&gt; %{&quot;memory.free.megs&quot; =&gt; 2400, &quot;memory.max.megs&quot; =&gt; 8234 ...}","ref":"Shin.Metrics.html#gauges/1","title":"Shin.Metrics.gauges/1","type":"function"},{"doc":"Returns a map of containing the specified gauge data, with new keysPass the metrics data followed by map of new_key =&gt; gauge_idExamples Metrics.map_gauges(metrics, %{hn: &quot;host.name&quot;, mm: &quot;memory.max.megs&quot;}) # =&gt; %{hn: &quot;production1&quot;, mm: 2048}","ref":"Shin.Metrics.html#map_gauges/2","title":"Shin.Metrics.map_gauges/2","type":"function"},{"doc":"Returns a map of containing the specified timer data, with new keysPass the metrics data followed by map of new_key =&gt; timer_idExamples Metrics.map_timers(metrics, %{timer1: &quot;org.opensaml.saml.metadata.resolver.impl.LocalDynamicMetadataResolver.exOverride.timer.resolve&quot;}) # =&gt; %{timer1: %{&quot;count&quot; =&gt; 1, &quot;duration_units&quot; =&gt; &quot;seconds&quot; ...}}","ref":"Shin.Metrics.html#map_timers/2","title":"Shin.Metrics.map_timers/2","type":"function"},{"doc":"Returns default (all) raw metrics from the IdP as a map.Pass an IdP as the only parameter.Examples {:ok, metrics} = Shin.Metrics.query(idp)","ref":"Shin.Metrics.html#query/1","title":"Shin.Metrics.query/1","type":"function"},{"doc":"Returns the specified raw metrics group from the IdP as a map.Pass an IdP struct as the first parameter and the name of the group as the second (as atom or binary)Examples {:ok, metrics} = Shin.Metrics.query(idp, :core)","ref":"Shin.Metrics.html#query/2","title":"Shin.Metrics.query/2","type":"function"},{"doc":"Return the value for a timer.Specify the metrics map and key for the timer map to be extracted.Examples Shin.Metrics.timer(metrics, &quot;org.opensaml.saml.metadata.resolver.impl.LocalDynamicMetadataResolver.exOverride.timer.resolve&quot;) # =&gt; %{&quot;count&quot; =&gt; 1, &quot;duration_units&quot; =&gt; &quot;seconds&quot; ...}","ref":"Shin.Metrics.html#timer/2","title":"Shin.Metrics.timer/2","type":"function"},{"doc":"List the keys for all timers in the metrics.Requires a metrics map as the only parameter.Examples Shin.Metrics.timer_ids(metrics) # =&gt; [&quot;org.opensaml.saml.metadata.resolver.impl.LocalDynamicMetadataResolver.exOverride.timer.resolve&quot; ...]","ref":"Shin.Metrics.html#timer_ids/1","title":"Shin.Metrics.timer_ids/1","type":"function"},{"doc":"Returns a map of all timers and their details from the metrics data.Examples Metrics.timers(metrics) # =&gt; %{&quot;org.opensaml.saml.metadata.resolver.impl.LocalDynamicMetadataResolver.exOverride.timer.resolve&quot; =&gt; %{} ...}","ref":"Shin.Metrics.html#timers/1","title":"Shin.Metrics.timers/1","type":"function"},{"doc":"This module contains functions for converting the metrics data returned from a Shibboleth IdP into simplified maps of data. Use Shin.metrics/1 or Shin.Metrics.query/1 to get the metrics data.","ref":"Shin.Reports.html","title":"Shin.Reports","type":"module"},{"doc":"A convenience function to produce a IdPInfo report (reformated &quot;idp&quot; metrics)Examples Shin.Reports.idp(metrics) # =&gt; {:ok, %Reports.IdPInfo{ ... }}","ref":"Shin.Reports.html#idp/1","title":"Shin.Reports.idp/1","type":"function"},{"doc":"Produce the specified report using the provided metricsThe reporter can be an alias (an atom already know to Shin) or any suitable module.Examples Reports.produce(metrics, :system_info) # =&gt; {:ok, %Shin.Reports.SystemInfo{ ... }} Reports.produce(metrics, Shin.Reports.IdPInfo) # =&gt; {:ok, %Reports.IdPInfo{ ... }}","ref":"Shin.Reports.html#produce/2","title":"Shin.Reports.produce/2","type":"function"},{"doc":"Returns a list reporter aliasesExamples Shin.Reports.reporter_aliases # =&gt; [:system_info, :idp_info]","ref":"Shin.Reports.html#reporter_aliases/0","title":"Shin.Reports.reporter_aliases/0","type":"function"},{"doc":"Returns a map of reporter modules.Examples Shin.Reports.reporter_modules # =&gt; [Shin.Reports.SystemInfo, Shin.Reports.IdPInfo]","ref":"Shin.Reports.html#reporter_modules/0","title":"Shin.Reports.reporter_modules/0","type":"function"},{"doc":"Returns a map of reporter aliases and modules.Examples Shin.Reports.reporters # =&gt; %{system_info: Shin.Reports.SystemInfo, idp_info: Shin.Reports.IdPInfo}","ref":"Shin.Reports.html#reporters/0","title":"Shin.Reports.reporters/0","type":"function"},{"doc":"A convenience function to produce a SystemInfo report (reformated &quot;core&quot; metrics)Examples Shin.Reports.system(metrics) # =&gt; {:ok, %Reports.SystemInfo{cores: 4, ...}}","ref":"Shin.Reports.html#system/1","title":"Shin.Reports.system/1","type":"function"},{"doc":"Queries and reloads sub-services at the IdP. Mostly it reloads subservices: things like logging, attribute filters, etc.","ref":"Shin.Service.html","title":"Shin.Service","type":"module"},{"doc":"Looks up information about the specified Shibboleth IdP sub-service, returning it in a results tuple.At the moment the only useful information concerns when the service restarted (or failed to restart)The service can be specified using the full Shibboleth service ID or a Shin service alias. These are listed in your IdP struct.Examples {:ok, info} = Shin.Service.query(idp, &quot;shibboleth.AttributeRegistryService&quot;)","ref":"Shin.Service.html#query/3","title":"Shin.Service.query/3","type":"function"},{"doc":"Looks up information about the specified Shibboleth IdP sub-service.At the moment the only useful information concerns when the service restarted (or failed to restart)The service can be specified using the full Shibboleth service ID or a Shin service alias. These are listed in your IdP struct.Examples info = Shin.Service.query!(idp, &quot;shibboleth.AttributeRegistryService&quot;)","ref":"Shin.Service.html#query!/3","title":"Shin.Service.query!/3","type":"function"},{"doc":"Sends a reload request for the specified service to the IdP. This should cause the IdP to reload the configuration for that service.Pass an IdP as the first parameter. The second parameter is either a full service ID or an alias provided by Shin.Examples {:ok, message} = Shin.Service.reload(idp, &quot;shibboleth.MetadataResolverService&quot;) {:ok, message} = Shin.Service.reload(idp, :metadata_resolver)","ref":"Shin.Service.html#reload/3","title":"Shin.Service.reload/3","type":"function"},{"doc":"Sends a reload request for the specified service to the IdP. This should cause the IdP to reload the configuration for that service.Pass an IdP as the first parameter. The second parameter is either a full service ID or an alias provided by Shin.Examples message = Shin.Service.reload!(idp, &quot;shibboleth.MetadataResolverService&quot;) message = Shin.Service.reload!(idp, :metadata_resolver)","ref":"Shin.Service.html#reload!/3","title":"Shin.Service.reload!/3","type":"function"},{"doc":"ShinShin is a simple Elixir client for the Shibboleth IdP's admin features. Currently it can collect metrics and trigger service reloads, fetch metadata and show released user attributes.Shin can be used to gather information about your IdP servers such as Java version and IdP version, and can also collect any other information defined as a metric within the IdP. Shin can return the raw data or reformat it into simpler reports.The Shibboleth IdP will automatically reload valid configuration files but may stop retrying if passed an incorrect file. Shin can be used to prompt the IdP to immediately reload parts of its configuration.Shin can also fetch entity metadata via the IdP and lookup user attribute information for specified SPs.","ref":"readme.html","title":"Shin","type":"extras"},{"doc":"The package can be installed by adding shin to your list of dependencies in mix.exs:def deps do [ {:shin, &quot;~&gt; 0.2.0&quot;} ] end","ref":"readme.html#installation","title":"Shin - Installation","type":"extras"},{"doc":"Defining an IdP targetTo define an IdP using a default configuration you only need the base URL of the IdP service {:ok, idp} = Shin.idp(&quot;https://idp.example.com/idp&quot;) # =&gt; \#{:ok, # %Shin.IdP{ # base_url: &quot;https://idp.example.com/idp&quot;, # metric_groups: [:core, :idp, :logging, :access, :metadata, :nameid, # :relyingparty, :registry, :resolver, :filter, :cas, :bean], # metrics_path: &quot;profile/admin/metrics&quot;, # no_dns_check: false, # reload_path: &quot;profile/admin/reload-service&quot;, # reloadable_services: %{ # access_control: &quot;shibboleth.ReloadableAccessControlService&quot;, # attribute_filter: &quot;shibboleth.AttributeFilterService&quot;, # attribute_registry: &quot;shibboleth.AttributeRegistryService&quot;, # attribute_resolver: &quot;shibboleth.AttributeResolverService&quot;, # cas_registry: &quot;shibboleth.ReloadableCASServiceRegistry&quot;, # managed_beans: &quot;shibboleth.ManagedBeanService&quot;, # metadata_resolver: &quot;shibboleth.MetadataResolverService&quot;, # nameid_generator: &quot;shibboleth.NameIdentifierGenerationService&quot;, # relying_party_resolver: &quot;shibboleth.RelyingPartyResolverService&quot; # }, # timeout: 2000 # }}If your IdP has different paths, metrics groups or reloadable services you can specify them as options.Functions in the top-level Shin module can also be passed a based URL if no configuration is needed.Downloading raw metrics {:ok, metrics} = Shin.metrics(idp) {:ok, metrics} = Shin.metrics(idp, :core) list_of_gauges = Shin.Metrics.gauge_ids(metrics) hostname = Shin.Metrics.gauge(metrics, &quot;host.name&quot;) Producing a simplified report {:ok, report} = Shin.report(idp, :system_info) report.cores #=&gt; 4 Triggering a service reload {:ok, message} = Shin.reload_service(idp, &quot;shibboleth.AttributeFilterService&quot;) {:ok, message} = Shin.reload_service(idp, :attribute_filter) Listing a user's attribute data released to an SP{:ok, attr_data} = Shin.attributes(idp, &quot;https://test.ukfederation.org.uk/entity&quot;, &quot;pete&quot;) Shin.Attributes.values(attr_data, &quot;eduPersonEntitlement&quot;) # =&gt; [&quot;urn:mace:dir:entitlement:common-lib-terms&quot;] Shin.Attributes.names(attr_data) #=&gt; [&quot;eduPersonEntitlement&quot;, &quot;eduPersonPrincipalName&quot;, &quot;eduPersonScopedAffiliation&quot;, # &quot;eduPersonUniqueID&quot;, &quot;o&quot;]Viewing a simulated SAML2 assertion containing user attributessaml_assertion_xml = Shin.assertion!(idp, &quot;https://test.ukfederation.org.uk/entity&quot;, &quot;pete&quot;)Fetching an SP's metadatametadata_xml = Shin.metadata!(idp, &quot;https://test.ukfederation.org.uk/entity&quot;)","ref":"readme.html#overview","title":"Shin - Overview","type":"extras"},{"doc":"This script outputs a small table showing the Java version used by each IdP#!/usr/bin/env elixir Mix.install( [ {:shin, &quot;~&gt; 0.2&quot;}, {:table_rex, &quot;~&gt; 3.1.1&quot;} ] ) urls = [ &quot;https://idp1.example.com/idp&quot;, &quot;https://idp2.example.com/idp&quot;, ] urls |&gt; Enum.map( fn url -&gt; Shin.report(url) |&gt; case do {:ok, report} -&gt; [url, report.java_version, report.java_vendor] {:error, _msg} -&gt; [url, &quot;error&quot;, &quot;error&quot;] end end ) |&gt; TableRex.quick_render!([&quot;IdP&quot;, &quot;Java Version&quot;, &quot;Java Vendor&quot;]) |&gt; IO.puts","ref":"readme.html#example-script","title":"Shin - Example Script","type":"extras"},{"doc":"Shibboleth IdP v3 or above (Shin is only tested against v4)IP address access control enabled for the client's IP address for the IdP's admin endpointsElixir 12 or greater, Erlang 24 or greater","ref":"readme.html#requirements","title":"Shin - Requirements","type":"extras"},{"doc":"Only IP address-based authnz is supported, but other methods may be added in later versions.","ref":"readme.html#limitations","title":"Shin - Limitations","type":"extras"},{"doc":"Full API documentation can be found at https://hexdocs.pm/shin.","ref":"readme.html#api-documentation","title":"Shin - API Documentation","type":"extras"},{"doc":"You can request new features by creating an issue, or submit a pull request with your contribution.","ref":"readme.html#contributing","title":"Shin - Contributing","type":"extras"},{"doc":"Shibboleth IdP v4 Metrics DocsShibboleth IdP v4 Reloadable Services DocsShibboleth IdP v4 Access ControlShin is named after the twenty-first letter of the Semitic abjads","ref":"readme.html#references","title":"Shin - References","type":"extras"},{"doc":"Copyright (c) 2022 Digital Identity Ltd, UKShin is MIT licensed.","ref":"readme.html#copyright-and-license","title":"Shin - Copyright and License","type":"extras"}]